Realtime
========

Supriya provides a set of APIs for interacting with the :term:`SuperCollider`
:term:`scsynth` synthesis server in realtime.

.. toctree::
   :hidden:

   servers
   nodes
   buses
   buffers
   async
